# `modisci` Python Package

The `modisci` Python package generates rasters of MODIS clumping index.

[Gregory H. Halverson](https://github.com/gregory-halverson-jpl) (they/them)<br>
[gregory.h.halverson@jpl.nasa.gov](mailto:gregory.h.halverson@jpl.nasa.gov)<br>
NASA Jet Propulsion Laboratory 329G

## References

1. He, L., J.M. Chen, J. Pisek, C. Schaaf, and A.H. Strahler. 2017. Global 500-m Foliage Clumping Index Data Derived from MODIS BRDF, 2006. ORNL DAAC, Oak Ridge, Tennessee, USA. .
2. He, LM; Chen, JM; Pisek, J; Schaaf, CB; Strahler, AH (2012). Global clumping index map derived from the MODIS BRDF product. REMOTE SENSING OF ENVIRONMENT, 119, 118-130.
